@@ -2,7 +2,7 @@ package Algorithm::Evolutionary;
 
 use Carp qw(croak);
 
-our $VERSION = '0.69_1'; #sexy number special
+our $VERSION = '0.74_1'; # Will we ever get to 1.0!!!
 
 # Preloaded methods go here.
 
@@ -69,7 +69,7 @@ web.
 <a href='http://opeal.sourceforge.net'>Sourceforge </a>. Latest aditions, and
 nightly updates, can be downloaded from there before they are uploaded
 to CPAN. That page also hosts the mailing list, as well as bug
-reports, news, updates, whatever.</p>
+reports, news, updates, work in progress, lots of stuff.</p>
 
 <p>In case the examples are hidden somewhere in the <code>.cpan</code> directory,
     you can also download them from <a
@@ -78,16 +78,44 @@ reports, news, updates, whatever.</p>
     href='https://sourceforge.net/project/showfiles.php?group_id=34080&package_id=54504'>-examples</a>
     tarballs in the file download area of that repository</p>
 
-<p>You can also get help from the <a href='https://sourceforge.net/forum/forum.php?forum_id=107255'>project forum</a> (where I usually hang around) or from <a href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing list</a> (information at <a href='https://lists.sourceforge.net/lists/listinfo/opeal-help'>its web site</a>)</p>
+<p>You can also get help from the <a
+href='https://sourceforge.net/forum/forum.php?forum_id=107255'>project
+forum</a> (where I usually hang around) or from <a
+href='mailto:opeal-help-request@lists.sourceforge.net'>the mailing
+list</a> (information at <a
+href='https://lists.sourceforge.net/lists/listinfo/opeal-help'>its web
+site</a>)</p> 
+
+<p>It might be also helpful for you to check out <a
+href='http://arxiv.org/abs/0908.0516'>Still doing evolutionary
+algorithms with Perl</a>, a gentle introduction to evolutionary
+algorithms in general and doing them using this module in particular.</p>
 
 <p>I have used this continously for my research all these year, and
 any search will return a number of papers; a journal article is
 already submitted, but meanwhile if you use it for any of your
-research, I would be very grateful if you quoted papers such as this
-one:</p>
+research, I would be very grateful if you quoted papers such as these
+(which are, of course, available under request of from your friendly
+ university librarian):</p>
 
 =end html
 
+ @article {springerlink:10.1007/s00500-009-0504-3,
+   author = {Merelo Guervs, Juan and Castillo, Pedro and Alba, Enrique},
+   affiliation = {Universidad de Granada Depto. Arquitectura y Tecnologa de Computadores, ETS Ingenieras Informtica y Telecomunicaciones Granada Spain},
+   title = {Algorithm::Evolutionary, a flexible Perl module for evolutionary computation},
+   journal = {Soft Computing - A Fusion of Foundations, Methodologies and Applications},
+   publisher = {Springer Berlin / Heidelberg},
+   issn = {1432-7643},
+   keyword = {Computer Science},
+   pages = {1091-1109},
+   volume = {14},
+   issue = {10},
+   url = {http://dx.doi.org/10.1007/s00500-009-0504-3},
+   note = {10.1007/s00500-009-0504-3},
+   year = {2010}
+ }
+
  @InProceedings{jj:2008:PPSN,
    author =	"Juan J. Merelo and  Antonio M. Mora and Pedro A. Castillo
                  and Juan L. J. Laredo and Lourdes Araujo and Ken C. Sharman
@@ -115,6 +143,8 @@ one:</p>
 
 =begin html
 
+<p>or the ArXiV one linked above.</p>
+
 <p>Some information on this paper and instructions for downloading the code used in it can
 be found in <a
 href='http://nohnes.wordpress.com/2008/09/21/paper-on-performance-of-asynchronous-distributed-evolutionary-algorithms-available-online/'>our
@@ -124,11 +154,15 @@ group blog</a></p>
 
 =head1 DISCUSSION, FEATURE REQUESTS
 
-Head to the CPAN forum for this module: L<http://www.cpanforum.com/dist/Algorithm-Evolutionary>
+Head to the CPAN forum for this module:
+L<http://www.cpanforum.com/dist/Algorithm-Evolutionary> 
 
 =head1 BUGS?
 
-Have you found any bugs? Use the CPAN tracker to inform about them (L<http://rt.cpan.org/Public/Dist/Display.html?Name=Algorithm-Evolutionary>) or email the author (below).
+Have you found any bugs? Use the CPAN tracker to inform about them
+(L<http://rt.cpan.org/Public/Dist/Display.html?Name=Algorithm-Evolutionary>)
+or email the author (below) or
+C<bug-algorithm-evolutionary@rt.cpan.org>. 
 
 =head1 AUTHOR
 
@@ -137,12 +171,14 @@ Have you found any bugs? Use the CPAN tracker to inform about them (L<http://rt.
 Main author and developer is J. J. Merelo, jmerelo (at) geneura.ugr.es
 who blogs at <a href='http://blojj.blogalia.com'>BloJJ</a> and
 twitters at <a
-href='http://twitter.com/jmerelo'>twitter.com/jmerelo</a>. There have
+href='http://twitter.com/jjmerelo'>twitter.com/jjmerelo</a>. There have
 also been some contributions from Javi Garca, fjgc (at) decsai.ugr.es
 and Pedro Castillo, pedro (at) geneura.ugr.es. Patient users that have
 submitted bugs include <a
-href='http://barbacana.net'>jamarier</a>. Bugs, requests and any kind
-of comment are welcome.
+href='http://barbacana.net'>jamarier</a> and Mike Gajewski. Bugs, requests and any kind
+of comment are welcome. <a href='http://alexm.org'>Alex Muntada</a>,
+from the <a href='http://barcelona.pm.org/'>Barcelona Perl
+Mongers</a>, helped me solve a problem with the Makefile.PL.
 
 =end html
 
@@ -156,8 +192,12 @@ C<cd examples; run_easy_ga.pl p_peaks.yaml>, which should run an
 simple GA on the P_Peaks deceptive function.
 
 Some other examples are installed: check out L<tide_bitstring.pl>,
-    L<tide_float.pl> and L<canonical-genetic-algorithm.pl>,
-which you can run and play with to get a taste of what EA programming is like, and then ammend, add and modify at leisure to create your own evolutionary algorithms. 
+    L<tide_float.pl> and L<canonical-genetic-algorithm.pl>, which you
+    can run and play with to get a taste of what EA programming is
+    like, and then ammend, add and modify at leisure to create your
+    own evolutionary algorithms. For a GUI example, check
+    L<rectangle-coverage.pl>, which uses L<Tk> to show the population
+    and its evolution.
 
 =head1 SEE ALSO
 
@@ -175,14 +215,17 @@ which you can run and play with to get a taste of what EA programming is like, a
 
 =item L<Algorithm::Evolutionary::Op::CanonicalGA>.
 
-=item L<XML> for an explanation of the XML format used
+=item L<XML> for an explanation of the XML format used.
 
 =item L<POE::Component::Algorithm::Evolutionary> if you want to mix
-evolutionary algorithms with anything else easily
+evolutionary algorithms with anything else easily.
+
+=item L<Algorithm::MasterMind::Evolutionary> uses this library to find
+the solution to the MasterMind Puzzle.
 
 You might also be interested in one of the other perl GA and
 evolutionary computation modules out there, such as
-L<AI::Genetic::Pro>
+L<AI::Genetic::Pro>.
 
 =back 
 
@@ -193,9 +236,9 @@ L<AI::Genetic::Pro>
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/07/24 12:58:45 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.2 2009/07/24 12:58:45 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/25 10:27:44 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary.pm,v 3.12 2010/09/25 10:27:44 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 3.2 $
+  $Revision: 3.12 $
 
 =cut
