@@ -53,10 +53,10 @@ easily. It is also TIEd so that strings can be handled as arrays.
 =cut
 
 package Algorithm::Evolutionary::Individual::String;
-use Carp;
-use Exporter;
 
-our ($VERSION) = ( '$Revision: 2.1 $ ' =~ / (\d+\.\d+)/ );
+use Carp;
+
+our $VERSION =   sprintf "%d.%03d", q$Revision: 3.3 $ =~ /(\d+)\.(\d+)/g; 
 
 use base 'Algorithm::Evolutionary::Individual::Base';
 
@@ -123,7 +123,7 @@ sub addAtom{
 
 =head2 fromString
 
-Similar to a copy ctor; creates a bitstring individual from a string
+Similar to a copy ctor; creates a bitstring individual from a string. Will be deprecated soon
 
 =cut
 
@@ -136,6 +136,23 @@ sub fromString  {
   return $self;
 }
 
+=head2 from_string
+
+Similar to a copy ctor; creates a bitstring individual from a string. Will be deprecated soon
+
+=cut
+
+sub from_string  {
+  my $class = shift; 
+  my $chars = shift;
+  my $str = shift;
+  my $self = Algorithm::Evolutionary::Individual::Base::new( $class );
+  $self->{'_chars'} = $chars;
+  $self->{'_str'} =  $str;
+  $self->{'_length'} = length( $str  );
+  return $self;
+}
+
 =head2 clone
 
 Similar to a copy ctor: creates a new individual from another one
@@ -175,7 +192,7 @@ starts at 0, as usual in Perl arrays.
 
 =cut
 
-sub Atom: lvalue {
+sub Atom {
   my $self = shift;
   my $index = shift;
   if ( @_ ) {
@@ -231,9 +248,9 @@ sub SPLICE {
   my $offset = shift;
   my $length = shift || length( $self->{'_str'} - $offset );
   my $sub_string =  substr( $self->{_str}, $offset, $length );
-  if ( @_ ) {
+#  if ( @_ ) {
     substr( $self->{_str}, $offset, $length ) = join("", @_ );
-  }
+#  } 
   return split(//,$sub_string);
 }
 
@@ -290,7 +307,7 @@ I would never ever do this in C++
 sub Chrom {
   my $self = shift;
   if ( defined $_[0] ) {
-	$self->{_str} = shift;
+    $self->{_str} = shift;
   }
   return $self->{_str}
 }
@@ -310,10 +327,9 @@ L<Algorithm::Evolutionary::Individual::BitString|Algorithm::Evolutionary::Indivi
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/String.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/25 08:16:59 $ 
+  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/String.pm,v 3.3 2010/09/25 08:16:59 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
-  $Name $
+  $Revision: 3.3 $
 
 =cut
